@@ -2,6 +2,29 @@
 (function($, JSON) {
     // Hang on in there. We have jQuery, 1.4.
     var BATCH_SIZE = 15;
+    var ALLOWED_COLON_WORDS = /(title|description|contributors|subject|content)$/i;
+
+    // Lucene special chars: + - && || ! ( ) { } [ ] ^ " ~ * ? : \
+    // Following regex contains Lucene special chars and punctuation chars (the colon it's treated separately).
+    // Chars with a "meaning" in regex syntax have been escaped.
+    var DISALLOWED_CHARS = /(\+|-|&|\||!|\(|\)|\{|\}|\[|\]|\^|"|~|\*|\?|\\|;|,|\.|\/|<|>)/g;
+
+    var remove_colons_from_query = function(query) {
+        var origin = query.split(':'),
+            cleaned = [],
+            i, match, len;
+        for (i=0, len=origin.length; i <len; i++) {
+            match = origin[i].search(ALLOWED_COLON_WORDS);
+            if (match > -1) {
+                cleaned.push(origin[i].substring(0, match));
+                cleaned.push(origin[i].substring(match).toLowerCase());
+                cleaned.push(':');
+            } else {
+                cleaned.push(origin[i]);
+            }
+        }
+        return cleaned.join('');
+    };
 
     var validate_year = function(year) {
         if (year.match(/^\d{4}$/)) {
@@ -11,8 +34,7 @@
     };
 
     var ElasticSearch = function($form) {
-        var search_urls = $form.data('server-urls'),
-            index_name = $form.data('index-name');
+        var search_urls = $form.data('server-urls');
         // List of callbacks during the various search stages.
         var start_query = [],
             empty_results = [],
@@ -22,8 +44,7 @@
 
         var get_url = function() {
             // Return an URL where to post the search query.
-            var index = Math.floor(Math.random() * search_urls.length);
-            return [search_urls[index], index_name, '_search'].join('/');
+            return search_urls[Math.floor(Math.random() * search_urls.length)];
         };
 
         var build_query = function(original) {
@@ -44,7 +65,7 @@
             if (original.term) {
                 queries.push({
                     query_string : {
-                        query: original.term,
+                        query: remove_colons_from_query(original.term.replace(DISALLOWED_CHARS, ' ')),
                         default_operator: "AND",
                         fields: [
                             "title^3",
